###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.6 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder
import base_item

manage_add_todo_form = HTMLFile('todo_add', globals())


def manage_add_todo(self, title, body, priority,
				   REQUEST=None):
	"Add an instance of the todo class"

	new_id = self.get_unique_id()

	self._setObject(new_id, todo(new_id, title, body, priority))

	if REQUEST is not None:

		REQUEST.RESPONSE.redirect(self.absolute_url())


class todo(
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"Documentation string"

	meta_type = 'Todo'
	icon = 'misc_/TodoFolder/Folder_icon.gif'

	_properties = (
		{'id':'title', 'type':'string'},
		#{'id':'short_body', 'type':'text'},
		{'id':'body', 'type':'text'},
		{'id':'priority', 'type':'int', 'select_widget':'priorities'},
		{'id':'status', 'type':'int', 'select_widget':'statuses'},
		)

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('View Todo',
		 ('',)),
		)

	manage_add_todo_form = manage_add_todo_form
	manage_add_todo = manage_add_todo

	meta_types = (
				{'name':'Todo', 'action':'manage_add_todo_form'},
			)

	index_html = HTMLFile('todo_index', globals())

	statuses = {
		0:'Completed',
		1:'Pending',
		2:'Cancelled',
		}

	priorities = {
		0:'Low',
		1:'Medium',
		2:'High'
		}


	def get_todos(self):
		"""Returns a list of the todos contained."""

		return self.objectValues('Todo')


	def __init__(self, id, title='', body='', priority=''):

		"Initialize the class instance"

		self.id = id
		self.title = title
		self.body = body
		self.priority = priority
		self.status = 1


	def render_status(self):
		"""Renders the status."""

		return self.statuses[self.status]


	def render_priority(self):
		"""Renders the priority."""

		return self.priorities[self.priority]


	def render_date(self):
		"""Renders the date this instance is contained within."""

		day = self.get_day()
		month = day.get_month()
		year = month.get_year()

		return "%s/%s/%s" % (day.id, month.id, year.id)


	def render_todo_indentation(self):
		"""Returns the 'indentation' level this todo has, according to parent todos."""

		indentation_html = ''

		for parent_todo in self.get_parent_todos():

			indentation_html = indentation_html + '--&gt;'

		return indentation_html


	def get_parent_todos(self):
		"""Returns a list of parent todos."""

		parent_todos = []

		ref = self.getParentNode()

		while 1:

			if ref.meta_type == 'Todo':

				parent_todos.append(ref)
				ref = ref.getParentNode()

			else:

				break

		return parent_todos


default__class_init__(todo)

